@@ -1,14 +1,13 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 from __future__ import unicode_literals
 
 from django.db import models
 
-__all__ = ['Config', ]
+__all__ = ['Config']
 
 
 class Config(models.Model):
 
-    #TODO: use index=True on key field
     key = models.CharField(max_length=75, unique=True)
-    value = models.TextField(null=True, blank=True)
\ No newline at end of file
+    value = models.TextField(null=True, blank=True)
